summaryrefslogtreecommitdiff
path: root/test/test_bootstrap.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/test_bootstrap.py')
-rw-r--r--test/test_bootstrap.py12
1 files changed, 8 insertions, 4 deletions
diff --git a/test/test_bootstrap.py b/test/test_bootstrap.py
index 2adbe33..4865ece 100644
--- a/test/test_bootstrap.py
+++ b/test/test_bootstrap.py
@@ -14,7 +14,7 @@ import pytest
'executable',
])
def test_bootstrap(
runner, yadm_y, paths, exists, executable, code, expect):
"""Test bootstrap command"""
if exists:
paths.bootstrap.write('')
@@ -25,7 +25,11 @@ def test_bootstrap(
f'exit {code}\n'
)
paths.bootstrap.chmod(0o775)
- run = runner(command=yadm_y('bootstrap'))
+ run = runner(command=yadm_cmd('bootstrap'))
assert run.code == code
- assert run.err == ''
- assert expect in run.out
+ if exists and executable:
+ assert run.err == ''
+ assert expect in run.out
+ else:
+ assert expect in run.err
+ assert run.out == ''
@@ -14,7 +14,7 @@ import pytest
])
def test_bootstrap(
- runner, yadm_y, paths, exists, executable, code, expect):
+ runner, yadm_cmd, paths, exists, executable, code, expect):
"""Test bootstrap command"""
if exists: